@@ -26,10 +26,12 @@
 #' @param x An object of class \code{orthobasisSp}.
 #' @param i,j Elements to extract (integer or empty): index of rows (i) and
 #'   columns (j).
-#' @return An object of class \code{orthobasisSp} , subclass \code{orthobasis}.
-#'   The MEMs are stored as a \code{data.frame}. It contains several attributes
-#'   (see \code{?attributes}) including: \itemize{\item \code{values}: The
-#'   associated eigenvalues. \item \code{listw}: The associated spatial
+#' @param drop A logical. If TRUE, object containing only one colum is converted in 
+#' vector
+#' @return An object of class \code{orthobasisSp} , subclass \code{orthobasis}. 
+#'   The MEMs are stored as a \code{data.frame}. It contains several attributes 
+#'   (see \code{?attributes}) including: \itemize{\item \code{values}: The 
+#'   associated eigenvalues. \item \code{listw}: The associated spatial 
 #'   weighting matrix (if \code{store.listw = TRUE}). }
 #' @author Stéphane Dray \email{stephane.dray@@univ-lyon1.fr}
 #' @seealso \code{\link[spdep]{nb2listw}} \code{\link[ade4]{orthobasis}}
@@ -143,7 +145,7 @@ orthobasis.listw <- function (listw,  wt = rep(1, length(listw$neighbours)),
 
 #' @rdname mem
 #' @export
-"[.orthobasisSp" <- function (x, i, j) {
+"[.orthobasisSp" <- function (x, i, j, drop = TRUE) {
     
     ## i: index of rows
     ## j: index of columns
@@ -160,7 +162,7 @@ orthobasis.listw <- function (listw,  wt = rep(1, length(listw$neighbours)),
     }
     attr(res,"call") <- match.call()
     attr(res,"class") <- attr(x,"class") 
-    if(ncol(res) == 1)
+    if(ncol(res) == 1 & (drop == TRUE))
         res <- as.vector(as.matrix(res))
     return(res)
 }
